@@ -8,9 +8,9 @@ use log::*;
 use rand::{thread_rng, Rng};
 use rayon::prelude::*;
 use solana_core::banking_stage::{create_test_recorder, BankingStage, BankingStageStats};
-use solana_core::cluster_info::ClusterInfo;
-use solana_core::cluster_info::Node;
 use solana_core::poh_recorder::WorkingBankEntry;
+use solana_gossip::cluster_info::ClusterInfo;
+use solana_gossip::cluster_info::Node;
 use solana_ledger::blockstore_processor::process_entries;
 use solana_ledger::entry::{next_hash, Entry};
 use solana_ledger::genesis_utils::{create_genesis_config, GenesisConfigInfo};
