@@ -5,8 +5,8 @@ extern crate test;
 use rand::{thread_rng, Rng};
 use solana_core::broadcast_stage::broadcast_metrics::TransmitShredsStats;
 use solana_core::broadcast_stage::{broadcast_shreds, get_broadcast_peers};
-use solana_core::cluster_info::{ClusterInfo, Node};
-use solana_core::contact_info::ContactInfo;
+use solana_gossip::cluster_info::{ClusterInfo, Node};
+use solana_gossip::contact_info::ContactInfo;
 use solana_ledger::shred::Shred;
 use solana_sdk::pubkey;
 use solana_sdk::timing::timestamp;
