@@ -4,16 +4,16 @@ extern crate solana_core;
 extern crate test;
 
 use log::*;
-use solana_core::cluster_info::{ClusterInfo, Node};
-use solana_core::contact_info::ContactInfo;
-use solana_core::max_slots::MaxSlots;
 use solana_core::retransmit_stage::retransmitter;
+use solana_gossip::cluster_info::{ClusterInfo, Node};
+use solana_gossip::contact_info::ContactInfo;
 use solana_ledger::entry::Entry;
 use solana_ledger::genesis_utils::{create_genesis_config, GenesisConfigInfo};
 use solana_ledger::leader_schedule_cache::LeaderScheduleCache;
 use solana_ledger::shred::Shredder;
 use solana_measure::measure::Measure;
 use solana_perf::packet::{Packet, Packets};
+use solana_rpc::max_slots::MaxSlots;
 use solana_runtime::bank::Bank;
 use solana_runtime::bank_forks::BankForks;
 use solana_sdk::hash::Hash;
