@@ -5,11 +5,7 @@ use self::{
     fail_entry_verification_broadcast_run::FailEntryVerificationBroadcastRun,
     standard_broadcast_run::StandardBroadcastRun,
 };
-use crate::contact_info::ContactInfo;
-use crate::crds_gossip_pull::CRDS_GOSSIP_PULL_CRDS_TIMEOUT_MS;
-use crate::weighted_shuffle::weighted_best;
 use crate::{
-    cluster_info::{ClusterInfo, ClusterInfoError},
     poh_recorder::WorkingBankEntry,
     result::{Error, Result},
 };
@@ -17,13 +13,19 @@ use crossbeam_channel::{
     Receiver as CrossbeamReceiver, RecvTimeoutError as CrossbeamRecvTimeoutError,
     Sender as CrossbeamSender,
 };
+use solana_gossip::{
+    cluster_info::{self, ClusterInfo, ClusterInfoError},
+    contact_info::ContactInfo,
+    crds_gossip_pull::CRDS_GOSSIP_PULL_CRDS_TIMEOUT_MS,
+    weighted_shuffle::weighted_best,
+};
 use solana_ledger::{blockstore::Blockstore, shred::Shred};
 use solana_measure::measure::Measure;
 use solana_metrics::{inc_new_counter_error, inc_new_counter_info};
 use solana_runtime::bank::Bank;
 use solana_sdk::timing::timestamp;
 use solana_sdk::{clock::Slot, pubkey::Pubkey};
-use solana_streamer::{sendmmsg::send_mmsg, socket::is_global};
+use solana_streamer::sendmmsg::send_mmsg;
 use std::sync::atomic::AtomicU64;
 use std::{
     collections::HashMap,
@@ -363,7 +365,6 @@ pub fn get_broadcast_peers(
     cluster_info: &ClusterInfo,
     stakes: Option<&HashMap<Pubkey, u64>>,
 ) -> (Vec<ContactInfo>, Vec<(u64, usize)>) {
-    use crate::cluster_info;
     let mut peers = cluster_info.tvu_peers();
     let peers_and_stakes = cluster_info::stake_weight_peers(&mut peers, stakes);
     (peers, peers_and_stakes)
@@ -387,15 +388,10 @@ pub fn broadcast_shreds(
     let mut shred_select = Measure::start("shred_select");
     let packets: Vec<_> = shreds
         .iter()
-        .filter_map(|shred| {
+        .map(|shred| {
             let broadcast_index = weighted_best(&peers_and_stakes, shred.seed());
-            let node = &peers[broadcast_index];
 
-            if is_global(&node.tvu) {
-                Some((&shred.payload, &node.tvu))
-            } else {
-                None
-            }
+            (&shred.payload, &peers[broadcast_index].tvu)
         })
         .collect();
     shred_select.stop();
@@ -445,8 +441,8 @@ fn num_live_peers(peers: &[ContactInfo]) -> i64 {
 #[cfg(test)]
 pub mod test {
     use super::*;
-    use crate::cluster_info::{ClusterInfo, Node};
     use crossbeam_channel::unbounded;
+    use solana_gossip::cluster_info::{ClusterInfo, Node};
     use solana_ledger::{
         blockstore::{make_slot_entries, Blockstore},
         entry::create_ticks,
