@@ -351,7 +351,7 @@ impl StandardBroadcastRun {
         if now - last > BROADCAST_PEER_UPDATE_INTERVAL_MS
             && self
                 .last_peer_update
-                .compare_and_swap(last, now, Ordering::Relaxed)
+                .compare_and_swap(now, last, Ordering::Relaxed)
                 == last
         {
             let mut w_broadcast_peer_cache = self.broadcast_peer_cache.write().unwrap();
@@ -494,7 +494,7 @@ impl BroadcastRun for StandardBroadcastRun {
 #[cfg(test)]
 mod test {
     use super::*;
-    use crate::cluster_info::{ClusterInfo, Node};
+    use solana_gossip::cluster_info::{ClusterInfo, Node};
     use solana_ledger::genesis_utils::create_genesis_config;
     use solana_ledger::{
         blockstore::Blockstore, entry::create_ticks, get_tmp_ledger_path,
