@@ -1,15 +1,15 @@
 //! The `repair_service` module implements the tools necessary to generate a thread which
 //! regularly finds missing shreds in the ledger and sends repair requests for those shreds
 use crate::{
-    cluster_info::ClusterInfo,
     cluster_info_vote_listener::VerifiedVoteReceiver,
     cluster_slots::ClusterSlots,
+    outstanding_requests::OutstandingRequests,
     repair_weight::RepairWeight,
     result::Result,
-    serve_repair::{RepairType, ServeRepair, DEFAULT_NONCE, REPAIR_PEERS_CACHE_CAPACITY},
+    serve_repair::{RepairType, ServeRepair},
 };
 use crossbeam_channel::{Receiver as CrossbeamReceiver, Sender as CrossbeamSender};
-use lru::LruCache;
+use solana_gossip::cluster_info::ClusterInfo;
 use solana_ledger::{
     blockstore::{Blockstore, SlotMeta},
     shred::Nonce,
@@ -34,6 +34,8 @@ use std::{
 pub type DuplicateSlotsResetSender = CrossbeamSender<Slot>;
 pub type DuplicateSlotsResetReceiver = CrossbeamReceiver<Slot>;
 
+pub type OutstandingRepairs = OutstandingRequests<RepairType>;
+
 #[derive(Default, Debug)]
 pub struct SlotRepairs {
     highest_shred_index: u64,
@@ -146,6 +148,7 @@ impl RepairService {
         repair_info: RepairInfo,
         cluster_slots: Arc<ClusterSlots>,
         verified_vote_receiver: VerifiedVoteReceiver,
+        outstanding_requests: Arc<RwLock<OutstandingRepairs>>,
     ) -> Self {
         let t_repair = Builder::new()
             .name("solana-repair-service".to_string())
@@ -158,6 +161,7 @@ impl RepairService {
                     repair_info,
                     &cluster_slots,
                     verified_vote_receiver,
+                    &outstanding_requests,
                 )
             })
             .unwrap();
@@ -173,6 +177,7 @@ impl RepairService {
         repair_info: RepairInfo,
         cluster_slots: &ClusterSlots,
         verified_vote_receiver: VerifiedVoteReceiver,
+        outstanding_requests: &RwLock<OutstandingRepairs>,
     ) {
         let mut repair_weight = RepairWeight::new(repair_info.bank_forks.read().unwrap().root());
         let serve_repair = ServeRepair::new(cluster_info.clone());
@@ -182,7 +187,6 @@ impl RepairService {
         let mut last_stats = Instant::now();
         let duplicate_slot_repair_statuses: HashMap<Slot, DuplicateSlotRepairStatus> =
             HashMap::new();
-        let mut peers_cache = LruCache::new(REPAIR_PEERS_CACHE_CAPACITY);
 
         loop {
             if exit.load(Ordering::Relaxed) {
@@ -192,6 +196,7 @@ impl RepairService {
             let mut set_root_elapsed;
             let mut get_votes_elapsed;
             let mut add_votes_elapsed;
+
             let repairs = {
                 let root_bank = repair_info.bank_forks.read().unwrap().root_bank().clone();
                 let new_root = root_bank.slot();
@@ -261,14 +266,17 @@ impl RepairService {
                 )
             };
 
+            let mut cache = HashMap::new();
             let mut send_repairs_elapsed = Measure::start("send_repairs_elapsed");
+            let mut outstanding_requests = outstanding_requests.write().unwrap();
             repairs.into_iter().for_each(|repair_request| {
                 if let Ok((to, req)) = serve_repair.repair_request(
                     &cluster_slots,
                     repair_request,
-                    &mut peers_cache,
+                    &mut cache,
                     &mut repair_stats,
                     &repair_info.repair_validators,
+                    &mut outstanding_requests,
                 ) {
                     repair_socket.send_to(&req, to).unwrap_or_else(|e| {
                         info!("{} repair req send_to({}) error {:?}", id, to, e);
@@ -468,6 +476,7 @@ impl RepairService {
         repair_stats: &mut RepairStats,
         repair_socket: &UdpSocket,
         repair_validators: &Option<HashSet<Pubkey>>,
+        outstanding_requests: &RwLock<OutstandingRepairs>,
     ) {
         duplicate_slot_repair_statuses.retain(|slot, status| {
             Self::update_duplicate_slot_repair_addr(
@@ -481,7 +490,9 @@ impl RepairService {
                 let repairs = Self::generate_duplicate_repairs_for_slot(&blockstore, *slot);
 
                 if let Some(repairs) = repairs {
+                    let mut outstanding_requests = outstanding_requests.write().unwrap();
                     for repair_type in repairs {
+                        let nonce = outstanding_requests.add_request(repair_type, timestamp());
                         if let Err(e) = Self::serialize_and_send_request(
                             &repair_type,
                             repair_socket,
@@ -489,7 +500,7 @@ impl RepairService {
                             &repair_addr,
                             serve_repair,
                             repair_stats,
-                            DEFAULT_NONCE,
+                            nonce,
                         ) {
                             info!(
                                 "repair req send_to {} ({}) error {:?}",
@@ -657,8 +668,8 @@ impl RepairService {
 #[cfg(test)]
 mod test {
     use super::*;
-    use crate::cluster_info::Node;
     use crossbeam_channel::unbounded;
+    use solana_gossip::cluster_info::Node;
     use solana_ledger::blockstore::{
         make_chaining_slot_entries, make_many_slot_entries, make_slot_entries,
     };
@@ -689,7 +700,7 @@ mod test {
                     MAX_ORPHANS,
                     MAX_REPAIR_LENGTH,
                     &HashSet::default(),
-                    None
+                    None,
                 ),
                 vec![RepairType::Orphan(2), RepairType::HighestShred(0, 0)]
             );
@@ -988,6 +999,7 @@ mod test {
             &mut RepairStats::default(),
             &UdpSocket::bind("0.0.0.0:0").unwrap(),
             &None,
+            &RwLock::new(OutstandingRequests::default()),
         );
         assert!(duplicate_slot_repair_statuses
             .get(&dead_slot)
@@ -1012,6 +1024,7 @@ mod test {
             &mut RepairStats::default(),
             &UdpSocket::bind("0.0.0.0:0").unwrap(),
             &None,
+            &RwLock::new(OutstandingRequests::default()),
         );
         assert_eq!(duplicate_slot_repair_statuses.len(), 1);
         assert!(duplicate_slot_repair_statuses.get(&dead_slot).is_some());
@@ -1029,6 +1042,7 @@ mod test {
             &mut RepairStats::default(),
             &UdpSocket::bind("0.0.0.0:0").unwrap(),
             &None,
+            &RwLock::new(OutstandingRequests::default()),
         );
         assert!(duplicate_slot_repair_statuses.is_empty());
     }
