@@ -1,5 +1,5 @@
 use {
-    crate::cluster_info::ClusterInfo,
+    solana_gossip::cluster_info::ClusterInfo,
     solana_sdk::{clock::Slot, pubkey::Pubkey},
     std::{
         collections::HashSet,
@@ -98,15 +98,7 @@ impl RpcHealth {
                         RpcHealthStatus::Behind { num_slots }
                     }
                 }
-                (latest_account_hash_slot, latest_trusted_validator_account_hash_slot) => {
-                    if latest_account_hash_slot.is_none() {
-                        warn!("health check: latest_account_hash_slot not available");
-                    }
-                    if latest_trusted_validator_account_hash_slot.is_none() {
-                        warn!("health check: latest_trusted_validator_account_hash_slot not available");
-                    }
-                    RpcHealthStatus::Unknown
-                }
+                _ => RpcHealthStatus::Unknown,
             }
         } else {
             // No trusted validator point of reference available, so this validator is healthy
