@@ -2,11 +2,8 @@
 
 use crate::{
     bigtable_upload_service::BigTableUploadService,
-    cluster_info::ClusterInfo,
-    max_slots::MaxSlots,
-    optimistically_confirmed_bank_tracker::OptimisticallyConfirmedBank,
     poh_recorder::PohRecorder,
-    rpc::{rpc_full::*, rpc_minimal::*, *},
+    rpc::{rpc_deprecated_v1_7::*, rpc_full::*, rpc_minimal::*, rpc_obsolete_v1_7::*, *},
     rpc_health::*,
     send_transaction_service::{LeaderInfo, SendTransactionService},
     validator::ValidatorExit,
@@ -18,14 +15,21 @@ use jsonrpc_http_server::{
 };
 use regex::Regex;
 use solana_client::rpc_cache::LargestAccountsCache;
+use solana_gossip::cluster_info::ClusterInfo;
 use solana_ledger::{blockstore::Blockstore, leader_schedule_cache::LeaderScheduleCache};
 use solana_metrics::inc_new_counter_info;
+use solana_rpc::{
+    max_slots::MaxSlots, optimistically_confirmed_bank_tracker::OptimisticallyConfirmedBank,
+};
 use solana_runtime::{
     bank_forks::{BankForks, SnapshotConfig},
     commitment::BlockCommitmentCache,
     snapshot_utils,
 };
-use solana_sdk::{hash::Hash, native_token::lamports_to_sol, pubkey::Pubkey};
+use solana_sdk::{
+    genesis_config::DEFAULT_GENESIS_DOWNLOAD_PATH, hash::Hash, native_token::lamports_to_sol,
+    pubkey::Pubkey,
+};
 use std::{
     collections::HashSet,
     net::SocketAddr,
@@ -34,6 +38,7 @@ use std::{
     sync::{mpsc::channel, Arc, Mutex, RwLock},
     thread::{self, Builder, JoinHandle},
 };
+use tokio::runtime;
 use tokio_util::codec::{BytesCodec, FramedRead};
 
 const LARGEST_ACCOUNTS_CACHE_DURATION: u64 = 60 * 60 * 2;
@@ -99,7 +104,7 @@ impl RpcRequestMiddleware {
 
     fn is_file_get_path(&self, path: &str) -> bool {
         match path {
-            "/genesis.tar.bz2" => true,
+            DEFAULT_GENESIS_DOWNLOAD_PATH => true,
             _ => {
                 if self.snapshot_config.is_some() {
                     self.snapshot_archive_path_regex.is_match(path)
@@ -111,8 +116,10 @@ impl RpcRequestMiddleware {
     }
 
     #[cfg(unix)]
-    async fn open_no_follow(path: impl AsRef<Path>) -> std::io::Result<tokio::fs::File> {
-        tokio::fs::OpenOptions::new()
+    async fn open_no_follow(path: impl AsRef<Path>) -> std::io::Result<tokio_02::fs::File> {
+        // Stuck on tokio 0.2 until the jsonrpc crates upgrade
+        use tokio_02::fs::os::unix::OpenOptionsExt;
+        tokio_02::fs::OpenOptions::new()
             .read(true)
             .write(false)
             .create(false)
@@ -122,16 +129,17 @@ impl RpcRequestMiddleware {
     }
 
     #[cfg(not(unix))]
-    async fn open_no_follow(path: impl AsRef<Path>) -> std::io::Result<tokio::fs::File> {
+    async fn open_no_follow(path: impl AsRef<Path>) -> std::io::Result<tokio_02::fs::File> {
         // TODO: Is there any way to achieve the same on Windows?
-        tokio::fs::File::open(path).await
+        // Stuck on tokio 0.2 until the jsonrpc crates upgrade
+        tokio_02::fs::File::open(path).await
     }
 
     fn process_file_get(&self, path: &str) -> RequestMiddlewareAction {
         let stem = path.split_at(1).1; // Drop leading '/' from path
         let filename = {
             match path {
-                "/genesis.tar.bz2" => {
+                DEFAULT_GENESIS_DOWNLOAD_PATH => {
                     inc_new_counter_info!("rpc-get_genesis", 1);
                     self.ledger_path.join(stem)
                 }
@@ -235,7 +243,8 @@ fn process_rest(bank_forks: &Arc<RwLock<BankForks>>, path: &str) -> Option<Strin
             let bank = r_bank_forks.root_bank();
             let total_supply = bank.capitalization();
             let non_circulating_supply =
-                crate::non_circulating_supply::calculate_non_circulating_supply(&bank).lamports;
+                solana_runtime::non_circulating_supply::calculate_non_circulating_supply(&bank)
+                    .lamports;
             Some(format!(
                 "{}",
                 lamports_to_sol(total_supply - non_circulating_supply)
@@ -290,17 +299,9 @@ impl JsonRpcService {
         )));
 
         let tpu_address = cluster_info.my_contact_info().tpu;
-
-        // sadly, some parts of our current rpc implemention block the jsonrpc's
-        // _socket-listening_ event loop for too long, due to (blocking) long IO or intesive CPU,
-        // causing no further processing of incoming requests and ultimatily innocent clients timing-out.
-        // So create a (shared) multi-threaded event_loop for jsonrpc and set its .threads() to 1,
-        // so that we avoid the single-threaded event loops from being created automatically by
-        // jsonrpc for threads when .threads(N > 1) is given.
         let runtime = Arc::new(
-            tokio::runtime::Builder::new_multi_thread()
-                .worker_threads(rpc_threads)
-                .thread_name("sol-rpc-el")
+            runtime::Builder::new_multi_thread()
+                .thread_name("rpc-runtime")
                 .enable_all()
                 .build()
                 .expect("Runtime"),
@@ -345,6 +346,7 @@ impl JsonRpcService {
             };
 
         let minimal_api = config.minimal_api;
+        let obsolete_v1_7_api = config.obsolete_v1_7_api;
         let (request_processor, receiver) = JsonRpcRequestProcessor::new(
             config,
             snapshot_config.clone(),
@@ -355,6 +357,7 @@ impl JsonRpcService {
             health.clone(),
             cluster_info.clone(),
             genesis_hash,
+            runtime,
             bigtable_ledger_storage,
             optimistically_confirmed_bank,
             largest_accounts_cache,
@@ -379,6 +382,23 @@ impl JsonRpcService {
 
         let ledger_path = ledger_path.to_path_buf();
 
+        // sadly, some parts of our current rpc implemention block the jsonrpc's
+        // _socket-listening_ event loop for too long, due to (blocking) long IO or intesive CPU,
+        // causing no further processing of incoming requests and ultimatily innocent clients timing-out.
+        // So create a (shared) multi-threaded event_loop for jsonrpc and set its .threads() to 1,
+        // so that we avoid the single-threaded event loops from being created automatically by
+        // jsonrpc for threads when .threads(N > 1) is given.
+        let event_loop = {
+            // Stuck on tokio 0.2 until the jsonrpc crates upgrade
+            tokio_02::runtime::Builder::new()
+                .core_threads(rpc_threads)
+                .threaded_scheduler()
+                .enable_all()
+                .thread_name("sol-rpc-el")
+                .build()
+                .unwrap()
+        };
+
         let (close_handle_sender, close_handle_receiver) = channel();
         let thread_hdl = Builder::new()
             .name("solana-jsonrpc".to_string())
@@ -388,6 +408,10 @@ impl JsonRpcService {
                 io.extend_with(rpc_minimal::MinimalImpl.to_delegate());
                 if !minimal_api {
                     io.extend_with(rpc_full::FullImpl.to_delegate());
+                    io.extend_with(rpc_deprecated_v1_7::DeprecatedV1_7Impl.to_delegate());
+                }
+                if obsolete_v1_7_api {
+                    io.extend_with(rpc_obsolete_v1_7::ObsoleteV1_7Impl.to_delegate());
                 }
 
                 let request_middleware = RpcRequestMiddleware::new(
@@ -400,7 +424,7 @@ impl JsonRpcService {
                     io,
                     move |_req: &hyper::Request<hyper::Body>| request_processor.clone(),
                 )
-                .event_loop_executor(runtime.handle().clone())
+                .event_loop_executor(event_loop.handle().clone())
                 .threads(1)
                 .cors(DomainsValidation::AllowOnly(vec![
                     AccessControlAllowOrigin::Any,
@@ -455,19 +479,22 @@ impl JsonRpcService {
 #[cfg(test)]
 mod tests {
     use super::*;
-    use crate::{
-        crds_value::{CrdsData, CrdsValue, SnapshotHash},
-        rpc::create_validator_exit,
-    };
+    use crate::rpc::create_validator_exit;
+    use solana_gossip::crds_value::{CrdsData, CrdsValue, SnapshotHash};
     use solana_ledger::{
         genesis_utils::{create_genesis_config, GenesisConfigInfo},
         get_tmp_ledger_path,
     };
-    use solana_runtime::{bank::Bank, bank_forks::ArchiveFormat, snapshot_utils::SnapshotVersion};
-    use solana_sdk::{genesis_config::ClusterType, signature::Signer};
+    use solana_runtime::{
+        bank::Bank, bank_forks::ArchiveFormat, snapshot_utils::SnapshotVersion,
+        snapshot_utils::DEFAULT_MAX_SNAPSHOTS_TO_RETAIN,
+    };
+    use solana_sdk::{
+        genesis_config::{ClusterType, DEFAULT_GENESIS_ARCHIVE},
+        signature::Signer,
+    };
     use std::io::Write;
     use std::net::{IpAddr, Ipv4Addr};
-    use tokio::runtime::Runtime;
 
     #[test]
     fn test_rpc_new() {
@@ -563,13 +590,14 @@ mod tests {
                 snapshot_path: PathBuf::from("/"),
                 archive_format: ArchiveFormat::TarBzip2,
                 snapshot_version: SnapshotVersion::default(),
+                maximum_snapshots_to_retain: DEFAULT_MAX_SNAPSHOTS_TO_RETAIN,
             }),
             bank_forks,
             RpcHealth::stub(),
         );
 
-        assert!(rrm.is_file_get_path("/genesis.tar.bz2"));
-        assert!(!rrm.is_file_get_path("genesis.tar.bz2"));
+        assert!(rrm.is_file_get_path(DEFAULT_GENESIS_DOWNLOAD_PATH));
+        assert!(!rrm.is_file_get_path(DEFAULT_GENESIS_ARCHIVE));
 
         assert!(!rrm.is_file_get_path("/snapshot.tar.bz2")); // This is a redirect
 
@@ -600,12 +628,12 @@ mod tests {
 
     #[test]
     fn test_process_file_get() {
-        let runtime = Runtime::new().unwrap();
+        let mut runtime = tokio_02::runtime::Runtime::new().unwrap();
 
         let ledger_path = get_tmp_ledger_path!();
         std::fs::create_dir(&ledger_path).unwrap();
 
-        let genesis_path = ledger_path.join("genesis.tar.bz2");
+        let genesis_path = ledger_path.join(DEFAULT_GENESIS_ARCHIVE);
         let rrm = RpcRequestMiddleware::new(
             ledger_path.clone(),
             None,
@@ -614,7 +642,7 @@ mod tests {
         );
 
         // File does not exist => request should fail.
-        let action = rrm.process_file_get("/genesis.tar.bz2");
+        let action = rrm.process_file_get(DEFAULT_GENESIS_DOWNLOAD_PATH);
         if let RequestMiddlewareAction::Respond { response, .. } = action {
             let response = runtime.block_on(response);
             let response = response.unwrap();
@@ -629,7 +657,7 @@ mod tests {
         }
 
         // Normal file exist => request should succeed.
-        let action = rrm.process_file_get("/genesis.tar.bz2");
+        let action = rrm.process_file_get(DEFAULT_GENESIS_DOWNLOAD_PATH);
         if let RequestMiddlewareAction::Respond { response, .. } = action {
             let response = runtime.block_on(response);
             let response = response.unwrap();
@@ -648,7 +676,7 @@ mod tests {
             symlink::symlink_file("wrong", &genesis_path).unwrap();
 
             // File is a symbolic link => request should fail.
-            let action = rrm.process_file_get("/genesis.tar.bz2");
+            let action = rrm.process_file_get(DEFAULT_GENESIS_DOWNLOAD_PATH);
             if let RequestMiddlewareAction::Respond { response, .. } = action {
                 let response = runtime.block_on(response);
                 let response = response.unwrap();
