@@ -1,22 +1,23 @@
 use crate::{
-    cluster_info::{ClusterInfo, ClusterInfoError},
     cluster_slots::ClusterSlots,
-    contact_info::ContactInfo,
     repair_response,
-    repair_service::RepairStats,
+    repair_service::{OutstandingRepairs, RepairStats},
+    request_response::RequestResponse,
     result::{Error, Result},
-    weighted_shuffle::weighted_best,
 };
 use bincode::serialize;
-use lru::LruCache;
-use rand::{
-    distributions::{Distribution, WeightedError, WeightedIndex},
-    Rng,
+use rand::distributions::{Distribution, WeightedIndex};
+use solana_gossip::{
+    cluster_info::{ClusterInfo, ClusterInfoError},
+    contact_info::ContactInfo,
+    weighted_shuffle::weighted_best,
+};
+use solana_ledger::{
+    blockstore::Blockstore,
+    shred::{Nonce, Shred},
 };
-use solana_ledger::{blockstore::Blockstore, shred::Nonce};
 use solana_measure::measure::Measure;
-use solana_measure::thread_mem_usage;
-use solana_metrics::{datapoint_debug, inc_new_counter_debug};
+use solana_metrics::inc_new_counter_debug;
 use solana_perf::packet::{limited_deserialize, Packets, PacketsRecycler};
 use solana_sdk::{
     clock::Slot,
@@ -26,7 +27,7 @@ use solana_sdk::{
 };
 use solana_streamer::streamer::{PacketReceiver, PacketSender};
 use std::{
-    collections::HashSet,
+    collections::{hash_map::Entry, HashMap, HashSet},
     net::SocketAddr,
     sync::atomic::{AtomicBool, Ordering},
     sync::{Arc, RwLock},
@@ -36,12 +37,6 @@ use std::{
 
 /// the number of slots to respond with when responding to `Orphan` requests
 pub const MAX_ORPHAN_REPAIR_RESPONSES: usize = 10;
-pub const DEFAULT_NONCE: u32 = 42;
-
-// Number of slots to cache their respective repair peers and sampling weights.
-pub(crate) const REPAIR_PEERS_CACHE_CAPACITY: usize = 128;
-// Limit cache entries ttl in order to avoid re-using outdated data.
-const REPAIR_PEERS_CACHE_TTL: Duration = Duration::from_secs(10);
 
 #[derive(Serialize, Deserialize, Debug, Clone, Copy, Hash, PartialEq, Eq)]
 pub enum RepairType {
@@ -60,6 +55,28 @@ impl RepairType {
     }
 }
 
+impl RequestResponse for RepairType {
+    type Response = Shred;
+    fn num_expected_responses(&self) -> u32 {
+        match self {
+            RepairType::Orphan(_) => (MAX_ORPHAN_REPAIR_RESPONSES + 1) as u32, // run_orphan uses <= MAX_ORPHAN_REPAIR_RESPONSES
+            RepairType::HighestShred(_, _) => 1,
+            RepairType::Shred(_, _) => 1,
+        }
+    }
+    fn verify_response(&self, response_shred: &Shred) -> bool {
+        match self {
+            RepairType::Orphan(slot) => response_shred.slot() <= *slot,
+            RepairType::HighestShred(slot, index) => {
+                response_shred.slot() as u64 == *slot && response_shred.index() as u64 >= *index
+            }
+            RepairType::Shred(slot, index) => {
+                response_shred.slot() as u64 == *slot && response_shred.index() as u64 == *index
+            }
+        }
+    }
+}
+
 #[derive(Default)]
 pub struct ServeRepairStats {
     pub total_packets: usize,
@@ -90,38 +107,7 @@ pub struct ServeRepair {
     cluster_info: Arc<ClusterInfo>,
 }
 
-// Cache entry for repair peers for a slot.
-pub(crate) struct RepairPeers {
-    asof: Instant,
-    peers: Vec<(Pubkey, /*ContactInfo.serve_repair:*/ SocketAddr)>,
-    weighted_index: WeightedIndex<u64>,
-}
-
-impl RepairPeers {
-    fn new(asof: Instant, peers: &[ContactInfo], weights: &[u64]) -> Result<Self> {
-        if peers.is_empty() {
-            return Err(Error::from(ClusterInfoError::NoPeers));
-        }
-        if peers.len() != weights.len() {
-            return Err(Error::from(WeightedError::InvalidWeight));
-        }
-        let weighted_index = WeightedIndex::new(weights)?;
-        let peers = peers
-            .iter()
-            .map(|peer| (peer.id, peer.serve_repair))
-            .collect();
-        Ok(Self {
-            asof,
-            peers,
-            weighted_index,
-        })
-    }
-
-    fn sample<R: Rng>(&self, rng: &mut R) -> (Pubkey, SocketAddr) {
-        let index = self.weighted_index.sample(rng);
-        self.peers[index]
-    }
-}
+type RepairCache = HashMap<Slot, (Vec<ContactInfo>, WeightedIndex<u64>)>;
 
 impl ServeRepair {
     /// Without a valid keypair gossip will not function. Only useful for tests.
@@ -319,7 +305,7 @@ impl ServeRepair {
         exit: &Arc<AtomicBool>,
     ) -> JoinHandle<()> {
         let exit = exit.clone();
-        let recycler = PacketsRecycler::new_without_limit("serve-repair-recycler-shrink-stats");
+        let recycler = PacketsRecycler::default();
         Builder::new()
             .name("solana-repair-listen".to_string())
             .spawn(move || {
@@ -347,7 +333,6 @@ impl ServeRepair {
                         Self::report_reset_stats(&me, &mut stats);
                         last_print = Instant::now();
                     }
-                    thread_mem_usage::datapoint("solana-repair-listen");
                 }
             })
             .unwrap()
@@ -362,9 +347,7 @@ impl ServeRepair {
         stats: &mut ServeRepairStats,
     ) {
         // iter over the packets
-        let allocated = thread_mem_usage::Allocatedp::default();
         packets.packets.iter().for_each(|packet| {
-            let start = allocated.get();
             let from_addr = packet.meta.addr();
             limited_deserialize(&packet.data[..packet.meta.size])
                 .into_iter()
@@ -376,10 +359,6 @@ impl ServeRepair {
                         let _ignore_disconnect = response_sender.send(rsp);
                     }
                 });
-            datapoint_debug!(
-                "solana-serve-repair-memory",
-                ("serve_repair", (allocated.get() - start) as i64, i64),
-            );
         });
     }
 
@@ -417,30 +396,37 @@ impl ServeRepair {
         Ok(out)
     }
 
-    pub(crate) fn repair_request(
+    pub fn repair_request(
         &self,
         cluster_slots: &ClusterSlots,
         repair_request: RepairType,
-        peers_cache: &mut LruCache<Slot, RepairPeers>,
+        cache: &mut RepairCache,
         repair_stats: &mut RepairStats,
         repair_validators: &Option<HashSet<Pubkey>>,
+        outstanding_requests: &mut OutstandingRepairs,
     ) -> Result<(SocketAddr, Vec<u8>)> {
         // find a peer that appears to be accepting replication and has the desired slot, as indicated
         // by a valid tvu port location
         let slot = repair_request.slot();
-        let repair_peers = match peers_cache.get(&slot) {
-            Some(entry) if entry.asof.elapsed() < REPAIR_PEERS_CACHE_TTL => entry,
-            _ => {
-                peers_cache.pop(&slot);
-                let repair_peers = self.repair_peers(repair_validators, slot);
+        let (repair_peers, weighted_index) = match cache.entry(slot) {
+            Entry::Occupied(entry) => entry.into_mut(),
+            Entry::Vacant(entry) => {
+                let repair_peers = self.repair_peers(&repair_validators, slot);
+                if repair_peers.is_empty() {
+                    return Err(Error::from(ClusterInfoError::NoPeers));
+                }
                 let weights = cluster_slots.compute_weights(slot, &repair_peers);
-                let repair_peers = RepairPeers::new(Instant::now(), &repair_peers, &weights)?;
-                peers_cache.put(slot, repair_peers);
-                peers_cache.get(&slot).unwrap()
+                debug_assert_eq!(weights.len(), repair_peers.len());
+                let weighted_index = WeightedIndex::new(weights)?;
+                entry.insert((repair_peers, weighted_index))
             }
         };
-        let (peer, addr) = repair_peers.sample(&mut rand::thread_rng());
-        let out = self.map_repair_request(&repair_request, &peer, repair_stats, DEFAULT_NONCE)?;
+        let n = weighted_index.sample(&mut rand::thread_rng());
+        let addr = repair_peers[n].serve_repair; // send the request to the peer's serve_repair port
+        let nonce =
+            outstanding_requests.add_request(repair_request, solana_sdk::timing::timestamp());
+        let repair_peer_id = repair_peers[n].id;
+        let out = self.map_repair_request(&repair_request, &repair_peer_id, repair_stats, nonce)?;
         Ok((addr, out))
     }
 
@@ -529,7 +515,11 @@ impl ServeRepair {
 
             if let Some(packet) = packet {
                 inc_new_counter_debug!("serve_repair-window-request-ledger", 1);
-                return Some(Packets::new_with_recycler_data(recycler, vec![packet])).unwrap();
+                return Some(Packets::new_with_recycler_data(
+                    recycler,
+                    "run_window_request",
+                    vec![packet],
+                ));
             }
         }
 
@@ -565,7 +555,11 @@ impl ServeRepair {
                 from_addr,
                 nonce,
             )?;
-            return Packets::new_with_recycler_data(recycler, vec![packet]);
+            return Some(Packets::new_with_recycler_data(
+                recycler,
+                "run_highest_window_request",
+                vec![packet],
+            ));
         }
         None
     }
@@ -578,7 +572,7 @@ impl ServeRepair {
         max_responses: usize,
         nonce: Nonce,
     ) -> Option<Packets> {
-        let mut res = Packets::new_with_recycler(recycler.clone(), 64).unwrap();
+        let mut res = Packets::new_with_recycler(recycler.clone(), 64, "run_orphan");
         if let Some(blockstore) = blockstore {
             // Try to find the next "n" parent slots of the input slot
             while let Ok(Some(meta)) = blockstore.meta(slot) {
@@ -615,14 +609,14 @@ impl ServeRepair {
 mod tests {
     use super::*;
     use crate::{repair_response, result::Error};
+    use solana_gossip::{socketaddr, socketaddr_any};
     use solana_ledger::get_tmp_ledger_path;
     use solana_ledger::{
         blockstore::make_many_slot_entries,
         blockstore_processor::fill_blockstore_slot_with_ticks,
-        shred::{
-            max_ticks_per_n_shreds, CodingShredHeader, DataShredHeader, Shred, ShredCommonHeader,
-        },
+        shred::{max_ticks_per_n_shreds, Shred},
     };
+    use solana_perf::packet::Packet;
     use solana_sdk::{hash::Hash, pubkey::Pubkey, timing::timestamp};
 
     #[test]
@@ -632,7 +626,7 @@ mod tests {
 
     /// test run_window_request responds with the right shred, and do not overrun
     fn run_highest_window_request(slot: Slot, num_slots: u64, nonce: Nonce) {
-        let recycler = PacketsRecycler::new_without_limit("");
+        let recycler = PacketsRecycler::default();
         solana_logger::setup();
         let ledger_path = get_tmp_ledger_path!();
         {
@@ -665,6 +659,8 @@ mod tests {
                 nonce,
             )
             .expect("packets");
+            let request = RepairType::HighestShred(slot, index);
+            verify_responses(&request, rv.packets.iter());
 
             let rv: Vec<Shred> = rv
                 .packets
@@ -700,7 +696,7 @@ mod tests {
 
     /// test window requests respond with the right shred, and do not overrun
     fn run_window_request(slot: Slot, nonce: Nonce) {
-        let recycler = PacketsRecycler::new_without_limit("");
+        let recycler = PacketsRecycler::default();
         solana_logger::setup();
         let ledger_path = get_tmp_ledger_path!();
         {
@@ -731,23 +727,10 @@ mod tests {
                 nonce,
             );
             assert!(rv.is_none());
-            let common_header = ShredCommonHeader {
-                slot,
-                index: 1,
-                ..ShredCommonHeader::default()
-            };
-            let data_header = DataShredHeader {
-                parent_offset: 1,
-                ..DataShredHeader::default()
-            };
-            let shred_info = Shred::new_empty_from_header(
-                common_header,
-                data_header,
-                CodingShredHeader::default(),
-            );
+            let shred = Shred::new_from_data(slot, 1, 1, None, false, false, 0, 2, 0);
 
             blockstore
-                .insert_shreds(vec![shred_info], None, false)
+                .insert_shreds(vec![shred], None, false)
                 .expect("Expect successful ledger write");
 
             let index = 1;
@@ -762,6 +745,8 @@ mod tests {
                 nonce,
             )
             .expect("packets");
+            let request = RepairType::Shred(slot, index);
+            verify_responses(&request, rv.packets.iter());
             let rv: Vec<Shred> = rv
                 .packets
                 .into_iter()
@@ -783,12 +768,14 @@ mod tests {
         let me = ContactInfo::new_localhost(&solana_sdk::pubkey::new_rand(), timestamp());
         let cluster_info = Arc::new(ClusterInfo::new_with_invalid_keypair(me));
         let serve_repair = ServeRepair::new(cluster_info.clone());
+        let mut outstanding_requests = OutstandingRepairs::default();
         let rv = serve_repair.repair_request(
             &cluster_slots,
             RepairType::Shred(0, 0),
-            &mut LruCache::new(100),
+            &mut HashMap::new(),
             &mut RepairStats::default(),
             &None,
+            &mut outstanding_requests,
         );
         assert_matches!(rv, Err(Error::ClusterInfoError(ClusterInfoError::NoPeers)));
 
@@ -813,9 +800,10 @@ mod tests {
             .repair_request(
                 &cluster_slots,
                 RepairType::Shred(0, 0),
-                &mut LruCache::new(100),
+                &mut HashMap::new(),
                 &mut RepairStats::default(),
                 &None,
+                &mut outstanding_requests,
             )
             .unwrap();
         assert_eq!(nxt.serve_repair, serve_repair_addr);
@@ -846,9 +834,10 @@ mod tests {
                 .repair_request(
                     &cluster_slots,
                     RepairType::Shred(0, 0),
-                    &mut LruCache::new(100),
+                    &mut HashMap::new(),
                     &mut RepairStats::default(),
                     &None,
+                    &mut outstanding_requests,
                 )
                 .unwrap();
             if rv.0 == serve_repair_addr {
@@ -868,7 +857,7 @@ mod tests {
 
     fn run_orphan(slot: Slot, num_slots: u64, nonce: Nonce) {
         solana_logger::setup();
-        let recycler = PacketsRecycler::new_without_limit("");
+        let recycler = PacketsRecycler::default();
         let ledger_path = get_tmp_ledger_path!();
         {
             let blockstore = Arc::new(Blockstore::open(&ledger_path).unwrap());
@@ -917,6 +906,9 @@ mod tests {
             .collect();
 
             // Verify responses
+            let request = RepairType::Orphan(slot);
+            verify_responses(&request, rv.iter());
+
             let expected: Vec<_> = (slot..slot + num_slots)
                 .rev()
                 .filter_map(|slot| {
@@ -939,7 +931,7 @@ mod tests {
     #[test]
     fn run_orphan_corrupted_shred_size() {
         solana_logger::setup();
-        let recycler = PacketsRecycler::new_without_limit("");
+        let recycler = PacketsRecycler::default();
         let ledger_path = get_tmp_ledger_path!();
         {
             let blockstore = Arc::new(Blockstore::open(&ledger_path).unwrap());
@@ -950,6 +942,7 @@ mod tests {
             assert_eq!(shreds[0].slot(), 1);
             assert_eq!(shreds[0].index(), 0);
             shreds[0].payload.push(10);
+            shreds[0].data_header.size = shreds[0].payload.len() as u16;
             blockstore
                 .insert_shreds(shreds, None, false)
                 .expect("Expect successful ledger write");
@@ -1022,9 +1015,10 @@ mod tests {
                 .repair_request(
                     &cluster_slots,
                     RepairType::Shred(0, 0),
-                    &mut LruCache::new(100),
+                    &mut HashMap::new(),
                     &mut RepairStats::default(),
                     &trusted_validators,
+                    &mut OutstandingRepairs::default(),
                 )
                 .is_err());
         }
@@ -1038,9 +1032,10 @@ mod tests {
             .repair_request(
                 &cluster_slots,
                 RepairType::Shred(0, 0),
-                &mut LruCache::new(100),
+                &mut HashMap::new(),
                 &mut RepairStats::default(),
                 &trusted_validators,
+                &mut OutstandingRepairs::default(),
             )
             .is_ok());
 
@@ -1058,10 +1053,71 @@ mod tests {
             .repair_request(
                 &cluster_slots,
                 RepairType::Shred(0, 0),
-                &mut LruCache::new(100),
+                &mut HashMap::new(),
                 &mut RepairStats::default(),
                 &None,
+                &mut OutstandingRepairs::default(),
             )
             .is_ok());
     }
+
+    #[test]
+    fn test_verify_response() {
+        let repair = RepairType::Orphan(9);
+        // Ensure new options are addded to this test
+        match repair {
+            RepairType::Orphan(_) => (),
+            RepairType::HighestShred(_, _) => (),
+            RepairType::Shred(_, _) => (),
+        };
+
+        let slot = 9;
+        let index = 5;
+
+        // Orphan
+        let mut shred = Shred::new_empty_data_shred();
+        shred.set_slot(slot);
+        let request = RepairType::Orphan(slot);
+        assert!(request.verify_response(&shred));
+        shred.set_slot(slot - 1);
+        assert!(request.verify_response(&shred));
+        shred.set_slot(slot + 1);
+        assert!(!request.verify_response(&shred));
+
+        // HighestShred
+        shred = Shred::new_empty_data_shred();
+        shred.set_slot(slot);
+        shred.set_index(index);
+        let request = RepairType::HighestShred(slot, index as u64);
+        assert!(request.verify_response(&shred));
+        shred.set_index(index + 1);
+        assert!(request.verify_response(&shred));
+        shred.set_index(index - 1);
+        assert!(!request.verify_response(&shred));
+        shred.set_slot(slot - 1);
+        shred.set_index(index);
+        assert!(!request.verify_response(&shred));
+        shred.set_slot(slot + 1);
+        assert!(!request.verify_response(&shred));
+
+        // Shred
+        shred = Shred::new_empty_data_shred();
+        shred.set_slot(slot);
+        shred.set_index(index);
+        let request = RepairType::Shred(slot, index as u64);
+        assert!(request.verify_response(&shred));
+        shred.set_index(index + 1);
+        assert!(!request.verify_response(&shred));
+        shred.set_slot(slot + 1);
+        shred.set_index(index);
+        assert!(!request.verify_response(&shred));
+    }
+
+    fn verify_responses<'a>(request: &RepairType, packets: impl Iterator<Item = &'a Packet>) {
+        for packet in packets {
+            let shred_payload = packet.data.to_vec();
+            let shred = Shred::new_from_serialized_shred(shred_payload).unwrap();
+            request.verify_response(&shred);
+        }
+    }
 }
