@@ -1,89 +1,88 @@
 //! The `validator` module hosts all the validator microservices.
 
-use {
-    crate::{
-        broadcast_stage::BroadcastStageType,
-        cache_block_meta_service::{CacheBlockMetaSender, CacheBlockMetaService},
-        cluster_info::{
-            ClusterInfo, Node, DEFAULT_CONTACT_DEBUG_INTERVAL_MILLIS,
-            DEFAULT_CONTACT_SAVE_INTERVAL_MILLIS,
-        },
-        cluster_info_vote_listener::VoteTracker,
-        completed_data_sets_service::CompletedDataSetsService,
-        consensus::{reconcile_blockstore_roots_with_tower, Tower},
-        contact_info::ContactInfo,
-        crds_gossip_pull::CRDS_GOSSIP_PULL_CRDS_TIMEOUT_MS,
-        gossip_service::GossipService,
-        max_slots::MaxSlots,
-        optimistically_confirmed_bank_tracker::{
-            OptimisticallyConfirmedBank, OptimisticallyConfirmedBankTracker,
-        },
-        poh_recorder::{PohRecorder, GRACE_TICKS_FACTOR, MAX_GRACE_SLOTS},
-        poh_service::{self, PohService},
-        rewards_recorder_service::{RewardsRecorderSender, RewardsRecorderService},
-        rpc::JsonRpcConfig,
-        rpc_pubsub_service::{PubSubConfig, PubSubService},
-        rpc_service::JsonRpcService,
-        rpc_subscriptions::RpcSubscriptions,
-        sample_performance_service::SamplePerformanceService,
-        serve_repair::ServeRepair,
-        serve_repair_service::ServeRepairService,
-        sigverify,
-        snapshot_packager_service::{PendingSnapshotPackage, SnapshotPackagerService},
-        tpu::{Tpu, DEFAULT_TPU_COALESCE_MS},
-        transaction_status_service::TransactionStatusService,
-        tvu::{Sockets, Tvu, TvuConfig},
+use crate::{
+    broadcast_stage::BroadcastStageType,
+    cache_block_meta_service::{CacheBlockMetaSender, CacheBlockMetaService},
+    cluster_info_vote_listener::VoteTracker,
+    completed_data_sets_service::CompletedDataSetsService,
+    consensus::{reconcile_blockstore_roots_with_tower, Tower},
+    poh_recorder::{PohRecorder, GRACE_TICKS_FACTOR, MAX_GRACE_SLOTS},
+    poh_service::{self, PohService},
+    rewards_recorder_service::{RewardsRecorderSender, RewardsRecorderService},
+    rpc::JsonRpcConfig,
+    rpc_service::JsonRpcService,
+    sample_performance_service::SamplePerformanceService,
+    serve_repair::ServeRepair,
+    serve_repair_service::ServeRepairService,
+    sigverify,
+    snapshot_packager_service::{PendingSnapshotPackage, SnapshotPackagerService},
+    tpu::{Tpu, DEFAULT_TPU_COALESCE_MS},
+    transaction_status_service::TransactionStatusService,
+    tvu::{Sockets, Tvu, TvuConfig},
+};
+use crossbeam_channel::{bounded, unbounded};
+use rand::{thread_rng, Rng};
+use solana_gossip::{
+    cluster_info::{
+        ClusterInfo, Node, DEFAULT_CONTACT_DEBUG_INTERVAL_MILLIS,
+        DEFAULT_CONTACT_SAVE_INTERVAL_MILLIS,
     },
-    crossbeam_channel::{bounded, unbounded},
-    rand::{thread_rng, Rng},
-    solana_ledger::{
-        bank_forks_utils,
-        blockstore::{Blockstore, BlockstoreSignals, CompletedSlotsReceiver, PurgeType},
-        blockstore_db::BlockstoreRecoveryMode,
-        blockstore_processor::{self, TransactionStatusSender},
-        leader_schedule::FixedSchedule,
-        leader_schedule_cache::LeaderScheduleCache,
-        poh::compute_hash_time_ns,
-    },
-    solana_measure::measure::Measure,
-    solana_metrics::datapoint_info,
-    solana_runtime::{
-        accounts_index::AccountSecondaryIndexes,
-        bank::Bank,
-        bank_forks::{BankForks, SnapshotConfig},
-        commitment::BlockCommitmentCache,
-        hardened_unpack::{open_genesis_config, MAX_GENESIS_ARCHIVE_UNPACKED_SIZE},
-    },
-    solana_sdk::{
-        clock::Slot,
-        epoch_schedule::MAX_LEADER_SCHEDULE_EPOCH_OFFSET,
-        genesis_config::GenesisConfig,
-        hash::Hash,
-        pubkey::Pubkey,
-        shred_version::compute_shred_version,
-        signature::{Keypair, Signer},
-        timing::timestamp,
-    },
-    solana_vote_program::vote_state::VoteState,
-    std::time::Instant,
-    std::{
-        collections::{HashMap, HashSet},
-        fmt,
-        net::SocketAddr,
-        ops::Deref,
-        path::{Path, PathBuf},
-        sync::{
-            atomic::{AtomicBool, AtomicU64, Ordering},
-            mpsc::Receiver,
-            Arc, Mutex, RwLock,
-        },
-        thread::{sleep, Builder},
-        time::Duration,
+    contact_info::ContactInfo,
+    gossip_service::GossipService,
+};
+use solana_ledger::{
+    bank_forks_utils,
+    blockstore::{Blockstore, BlockstoreSignals, CompletedSlotsReceiver, PurgeType},
+    blockstore_db::BlockstoreRecoveryMode,
+    blockstore_processor::{self, TransactionStatusSender},
+    leader_schedule::FixedSchedule,
+    leader_schedule_cache::LeaderScheduleCache,
+    poh::compute_hash_time_ns,
+};
+use solana_measure::measure::Measure;
+use solana_metrics::datapoint_info;
+use solana_rpc::{
+    max_slots::MaxSlots,
+    optimistically_confirmed_bank_tracker::{
+        OptimisticallyConfirmedBank, OptimisticallyConfirmedBankTracker,
     },
+    rpc_pubsub_service::{PubSubConfig, PubSubService},
+    rpc_subscriptions::RpcSubscriptions,
+};
+use solana_runtime::{
+    accounts_index::AccountSecondaryIndexes,
+    bank::Bank,
+    bank_forks::{BankForks, SnapshotConfig},
+    commitment::BlockCommitmentCache,
+    hardened_unpack::{open_genesis_config, MAX_GENESIS_ARCHIVE_UNPACKED_SIZE},
+};
+use solana_sdk::{
+    clock::Slot,
+    epoch_schedule::MAX_LEADER_SCHEDULE_EPOCH_OFFSET,
+    genesis_config::GenesisConfig,
+    hash::Hash,
+    pubkey::Pubkey,
+    shred_version::compute_shred_version,
+    signature::{Keypair, Signer},
+    timing::timestamp,
+};
+use solana_vote_program::vote_state::VoteState;
+use std::time::Instant;
+use std::{
+    collections::HashSet,
+    fmt,
+    net::SocketAddr,
+    ops::Deref,
+    path::{Path, PathBuf},
+    sync::atomic::{AtomicBool, AtomicU64, Ordering},
+    sync::mpsc::Receiver,
+    sync::{Arc, Mutex, RwLock},
+    thread::{sleep, Builder},
+    time::Duration,
 };
 
 const MAX_COMPLETED_DATA_SETS_IN_CHANNEL: usize = 100_000;
-const WAIT_FOR_SUPERMAJORITY_THRESHOLD_PERCENT: u64 = 80;
+const WAIT_FOR_SUPERMAJORITY_THRESHOLD_PERCENT: u64 = 90;
 
 #[derive(Debug)]
 pub struct ValidatorConfig {
@@ -410,7 +409,6 @@ impl Validator {
             &exit,
             config.enforce_ulimit_nofile,
             &start_progress,
-            config.no_poh_speed_test,
         );
 
         *start_progress.write().unwrap() = ValidatorStartProgress::StartingServices;
@@ -471,12 +469,12 @@ impl Validator {
         let optimistically_confirmed_bank =
             OptimisticallyConfirmedBank::locked_from_bank_forks_root(&bank_forks);
 
-        let rpc_subscriptions = Arc::new(RpcSubscriptions::new_with_config(
+        let subscriptions = Arc::new(RpcSubscriptions::new_with_vote_subscription(
             &exit,
             bank_forks.clone(),
             block_commitment_cache.clone(),
             optimistically_confirmed_bank.clone(),
-            &config.pubsub_config,
+            config.pubsub_config.enable_vote_subscription,
         ));
 
         let max_slots = Arc::new(MaxSlots::default());
@@ -485,7 +483,7 @@ impl Validator {
         let completed_data_sets_service = CompletedDataSetsService::new(
             completed_data_sets_receiver,
             blockstore.clone(),
-            rpc_subscriptions.clone(),
+            subscriptions.clone(),
             &exit,
             max_slots.clone(),
         );
@@ -563,25 +561,19 @@ impl Validator {
                 if config.rpc_config.minimal_api {
                     None
                 } else {
-                    let (trigger, pubsub_service) = PubSubService::new(
+                    Some(PubSubService::new(
                         config.pubsub_config.clone(),
-                        &rpc_subscriptions,
+                        &subscriptions,
                         rpc_pubsub_addr,
-                    );
-                    config
-                        .validator_exit
-                        .write()
-                        .unwrap()
-                        .register_exit(Box::new(move || trigger.cancel()));
-
-                    Some(pubsub_service)
+                        &exit,
+                    ))
                 },
                 Some(OptimisticallyConfirmedBankTracker::new(
                     bank_notification_receiver,
                     &exit,
                     bank_forks.clone(),
                     optimistically_confirmed_bank,
-                    rpc_subscriptions.clone(),
+                    subscriptions.clone(),
                 )),
                 Some(bank_notification_sender),
             )
@@ -638,6 +630,7 @@ impl Validator {
                     snapshot_hash,
                     &exit,
                     &cluster_info,
+                    snapshot_config.maximum_snapshots_to_retain,
                 );
                 (
                     Some(snapshot_packager_service),
@@ -647,6 +640,10 @@ impl Validator {
                 (None, None)
             };
 
+        if !config.no_poh_speed_test {
+            check_poh_speed(&genesis_config, None);
+        }
+
         let waited_for_supermajority = if let Ok(waited) = wait_for_supermajority(
             config,
             &bank,
@@ -717,7 +714,7 @@ impl Validator {
             },
             blockstore.clone(),
             ledger_signal_receiver,
-            &rpc_subscriptions,
+            &subscriptions,
             &poh_recorder,
             tower,
             &leader_schedule_cache,
@@ -763,7 +760,7 @@ impl Validator {
             node.sockets.tpu,
             node.sockets.tpu_forwards,
             node.sockets.broadcast,
-            &rpc_subscriptions,
+            &subscriptions,
             transaction_status_sender,
             &blockstore,
             &config.broadcast_stage_type,
@@ -1040,7 +1037,6 @@ fn new_banks_from_ledger(
     exit: &Arc<AtomicBool>,
     enforce_ulimit_nofile: bool,
     start_progress: &Arc<RwLock<ValidatorStartProgress>>,
-    no_poh_speed_test: bool,
 ) -> (
     GenesisConfig,
     BankForks,
@@ -1074,10 +1070,6 @@ fn new_banks_from_ledger(
         }
     }
 
-    if !no_poh_speed_test {
-        check_poh_speed(&genesis_config, None);
-    }
-
     let BlockstoreSignals {
         mut blockstore,
         ledger_signal_receiver,
@@ -1197,6 +1189,7 @@ fn new_banks_from_ledger(
             &snapshot_config.snapshot_package_output_path,
             snapshot_config.archive_format,
             Some(&bank_forks.root_bank().get_thread_pool()),
+            snapshot_config.maximum_snapshots_to_retain,
         )
         .unwrap_or_else(|err| {
             error!("Unable to create snapshot: {}", err);
@@ -1417,10 +1410,6 @@ fn wait_for_supermajority(
         let gossip_stake_percent = get_stake_percent_in_gossip(&bank, &cluster_info, i % 10 == 0);
 
         if gossip_stake_percent >= WAIT_FOR_SUPERMAJORITY_THRESHOLD_PERCENT {
-            info!(
-                "Supermajority reached, {}% active stake detected, starting up now.",
-                gossip_stake_percent,
-            );
             break;
         }
         // The normal RPC health checks don't apply as the node is waiting, so feign health to
@@ -1443,24 +1432,32 @@ fn report_target_features() {
         }
     );
 
-    #[cfg(any(target_arch = "x86", target_arch = "x86_64"))]
+    // We exclude Mac OS here to be compatible with computers that have Mac M1 chips.
+    // For these computers, one must install rust/cargo/brew etc. using Rosetta 2,
+    // which allows them to run software targeted for x86_64 on an aarch64.
+    // Hence the code below will run on these machines (target_arch="x86_64")
+    // if we don't exclude with target_os="macos".
+    //
+    // It's going to require more more work to get Solana building
+    // on Mac M1's without Rosetta,
+    // and when that happens we should remove this
+    // (the feature flag for code targeting that is target_arch="aarch64")
+    #[cfg(all(
+        any(target_arch = "x86", target_arch = "x86_64"),
+        not(target_os = "macos")
+    ))]
     {
-        unsafe { check_avx() };
-    }
-}
-
-// Validator binaries built on a machine with AVX support will generate invalid opcodes
-// when run on machines without AVX causing a non-obvious process abort.  Instead detect
-// the mismatch and error cleanly.
-#[target_feature(enable = "avx")]
-unsafe fn check_avx() {
-    if is_x86_feature_detected!("avx") {
-        info!("AVX detected");
-    } else {
-        error!(
-            "Your machine does not have AVX support, please rebuild from source on your machine"
-        );
-        abort();
+        // Validator binaries built on a machine with AVX support will generate invalid opcodes
+        // when run on machines without AVX causing a non-obvious process abort.  Instead detect
+        // the mismatch and error cleanly.
+        if is_x86_feature_detected!("avx") {
+            info!("AVX detected");
+        } else {
+            error!(
+                "Your machine does not have AVX support, please rebuild from source on your machine"
+            );
+            abort();
+        }
     }
 }
 
@@ -1473,20 +1470,7 @@ fn get_stake_percent_in_gossip(bank: &Bank, cluster_info: &ClusterInfo, log: boo
     let mut offline_nodes = vec![];
 
     let mut total_activated_stake = 0;
-    let now = timestamp();
-    // Nodes contact infos are saved to disk and restored on validator startup.
-    // Staked nodes entries will not expire until an epoch after. So it
-    // is necessary here to filter for recent entries to establish liveness.
-    let peers: HashMap<_, _> = cluster_info
-        .all_tvu_peers()
-        .into_iter()
-        .filter(|node| {
-            let age = now.saturating_sub(node.wallclock);
-            // Contact infos are refreshed twice during this period.
-            age < CRDS_GOSSIP_PULL_CRDS_TIMEOUT_MS
-        })
-        .map(|node| (node.id, node))
-        .collect();
+    let all_tvu_peers = cluster_info.all_tvu_peers();
     let my_shred_version = cluster_info.my_shred_version();
     let my_id = cluster_info.id();
 
@@ -1502,7 +1486,10 @@ fn get_stake_percent_in_gossip(bank: &Bank, cluster_info: &ClusterInfo, log: boo
             .map(|vote_state| vote_state.node_pubkey)
             .unwrap_or_default();
 
-        if let Some(peer) = peers.get(&vote_state_node_pubkey) {
+        if let Some(peer) = all_tvu_peers
+            .iter()
+            .find(|peer| peer.id == vote_state_node_pubkey)
+        {
             if peer.shred_version == my_shred_version {
                 trace!(
                     "observed {} in gossip, (activated_stake={})",
@@ -1522,22 +1509,21 @@ fn get_stake_percent_in_gossip(bank: &Bank, cluster_info: &ClusterInfo, log: boo
         }
     }
 
-    let online_stake_percentage = (online_stake as f64 / total_activated_stake as f64) * 100.;
     if log {
         info!(
-            "{:.3}% of active stake visible in gossip",
-            online_stake_percentage
+            "{}% of active stake visible in gossip",
+            online_stake * 100 / total_activated_stake
         );
 
         if !wrong_shred_nodes.is_empty() {
             info!(
-                "{:.3}% of active stake has the wrong shred version in gossip",
-                (wrong_shred_stake as f64 / total_activated_stake as f64) * 100.,
+                "{}% of active stake has the wrong shred version in gossip",
+                wrong_shred_stake * 100 / total_activated_stake,
             );
             for (stake, identity) in wrong_shred_nodes {
                 info!(
-                    "    {:.3}% - {}",
-                    (stake as f64 / total_activated_stake as f64) * 100.,
+                    "    {}% - {}",
+                    stake * 100 / total_activated_stake,
                     identity
                 );
             }
@@ -1545,20 +1531,20 @@ fn get_stake_percent_in_gossip(bank: &Bank, cluster_info: &ClusterInfo, log: boo
 
         if !offline_nodes.is_empty() {
             info!(
-                "{:.3}% of active stake is not visible in gossip",
-                (offline_stake as f64 / total_activated_stake as f64) * 100.
+                "{}% of active stake is not visible in gossip",
+                offline_stake * 100 / total_activated_stake
             );
             for (stake, identity) in offline_nodes {
                 info!(
-                    "    {:.3}% - {}",
-                    (stake as f64 / total_activated_stake as f64) * 100.,
+                    "    {}% - {}",
+                    stake * 100 / total_activated_stake,
                     identity
                 );
             }
         }
     }
 
-    online_stake_percentage as u64
+    online_stake * 100 / total_activated_stake
 }
 
 // Cleanup anything that looks like an accounts append-vec
@@ -1650,11 +1636,9 @@ mod tests {
             }
             drop(blockstore);
 
-            // this purges and compacts all slots greater than or equal to 5
             backup_and_clear_blockstore(&blockstore_path, 5, 2);
 
             let blockstore = Blockstore::open(&blockstore_path).unwrap();
-            // assert that slots less than 5 aren't affected
             assert!(blockstore.meta(4).unwrap().unwrap().next_slots.is_empty());
             for i in 5..10 {
                 assert!(blockstore
