@@ -1,7 +1,5 @@
-use crate::{
-    cluster_info_vote_listener::VerifiedLabelVotePacketsReceiver, crds_value::CrdsValueLabel,
-    result::Result,
-};
+use crate::{cluster_info_vote_listener::VerifiedLabelVotePacketsReceiver, result::Result};
+use solana_gossip::crds_value::CrdsValueLabel;
 use solana_perf::packet::Packets;
 use solana_sdk::clock::Slot;
 use std::{
@@ -59,7 +57,8 @@ impl VerifiedVotePackets {
         }
         let packets = votes
             .into_iter()
-            .flat_map(|(_, (_, packets))| packets.packets.clone())
+            .flat_map(|(_, (_, packets))| &packets.packets)
+            .cloned()
             .collect();
         (new_update_version, Packets::new(packets))
     }
@@ -104,7 +103,7 @@ mod tests {
         // Only the nonempty packet had a timestamp greater than 1
         let (new_update_version, updates) = verified_vote_packets.get_latest_votes(1);
         assert_eq!(new_update_version, 2);
-        assert_eq!(updates.packets.is_empty(), false);
+        assert!(!updates.packets.is_empty());
 
         // If the given timestamp is greater than all timestamps in any update,
         // returned timestamp should be the same as the given timestamp, and
