@@ -2,14 +2,13 @@
 //!   blockstore and retransmitting where required
 //!
 use crate::{
-    cluster_info::ClusterInfo,
     cluster_info_vote_listener::VerifiedVoteReceiver,
     cluster_slots::ClusterSlots,
     completed_data_sets_service::CompletedDataSetsSender,
+    outstanding_requests::OutstandingRequests,
     repair_response,
-    repair_service::{RepairInfo, RepairService},
+    repair_service::{OutstandingRepairs, RepairInfo, RepairService},
     result::{Error, Result},
-    serve_repair::DEFAULT_NONCE,
 };
 use crossbeam_channel::{
     unbounded, Receiver as CrossbeamReceiver, RecvTimeoutError, Sender as CrossbeamSender,
@@ -17,6 +16,7 @@ use crossbeam_channel::{
 use rayon::iter::IntoParallelRefMutIterator;
 use rayon::iter::ParallelIterator;
 use rayon::ThreadPool;
+use solana_gossip::cluster_info::ClusterInfo;
 use solana_ledger::{
     blockstore::{self, Blockstore, BlockstoreInsertionMetrics, MAX_DATA_SHREDS_PER_SLOT},
     leader_schedule_cache::LeaderScheduleCache,
@@ -28,6 +28,7 @@ use solana_rayon_threadlimit::get_thread_count;
 use solana_runtime::{bank::Bank, bank_forks::BankForks};
 use solana_sdk::{clock::Slot, packet::PACKET_DATA_SIZE, pubkey::Pubkey, timing::duration_as_ms};
 use solana_streamer::streamer::PacketSender;
+use std::collections::HashSet;
 use std::{
     net::{SocketAddr, UdpSocket},
     sync::atomic::{AtomicBool, Ordering},
@@ -123,13 +124,50 @@ fn run_check_duplicate(
     Ok(())
 }
 
-fn verify_repair(repair_info: &Option<RepairMeta>) -> bool {
-    repair_info
+fn verify_repair(
+    outstanding_requests: &mut OutstandingRepairs,
+    shred: &Shred,
+    repair_meta: &Option<RepairMeta>,
+) -> bool {
+    repair_meta
         .as_ref()
-        .map(|repair_info| repair_info.nonce == DEFAULT_NONCE)
+        .map(|repair_meta| {
+            outstanding_requests.register_response(
+                repair_meta.nonce,
+                &shred,
+                solana_sdk::timing::timestamp(),
+            )
+        })
         .unwrap_or(true)
 }
 
+fn prune_shreds_invalid_repair(
+    shreds: &mut Vec<Shred>,
+    repair_infos: &mut Vec<Option<RepairMeta>>,
+    outstanding_requests: &Arc<RwLock<OutstandingRepairs>>,
+) {
+    assert_eq!(shreds.len(), repair_infos.len());
+    let mut i = 0;
+    let mut removed = HashSet::new();
+    {
+        let mut outstanding_requests = outstanding_requests.write().unwrap();
+        shreds.retain(|shred| {
+            let should_keep = (
+                verify_repair(&mut outstanding_requests, &shred, &repair_infos[i]),
+                i += 1,
+            )
+                .0;
+            if !should_keep {
+                removed.insert(i - 1);
+            }
+            should_keep
+        });
+    }
+    i = 0;
+    repair_infos.retain(|_repair_info| (!removed.contains(&i), i += 1).0);
+    assert_eq!(shreds.len(), repair_infos.len());
+}
+
 fn run_insert<F>(
     shred_receiver: &CrossbeamReceiver<(Vec<Shred>, Vec<Option<RepairMeta>>)>,
     blockstore: &Arc<Blockstore>,
@@ -137,6 +175,7 @@ fn run_insert<F>(
     handle_duplicate: F,
     metrics: &mut BlockstoreInsertionMetrics,
     completed_data_sets_sender: &CompletedDataSetsSender,
+    outstanding_requests: &Arc<RwLock<OutstandingRepairs>>,
 ) -> Result<()>
 where
     F: Fn(Shred),
@@ -148,11 +187,7 @@ where
         repair_infos.extend(more_repair_infos);
     }
 
-    assert_eq!(shreds.len(), repair_infos.len());
-    let mut i = 0;
-    shreds.retain(|_shred| (verify_repair(&repair_infos[i]), i += 1).0);
-    repair_infos.retain(|repair_info| verify_repair(&repair_info));
-    assert_eq!(shreds.len(), repair_infos.len());
+    prune_shreds_invalid_repair(&mut shreds, &mut repair_infos, outstanding_requests);
 
     let (completed_data_sets, inserted_indices) = blockstore.insert_shreds_handle_duplicate(
         shreds,
@@ -235,13 +270,6 @@ where
                                     }
                                 };
                                 if shred_filter(&shred, last_root) {
-                                    // Mark slot as dead if the current shred is on the boundary
-                                    // of max shreds per slot. However, let the current shred
-                                    // get retransmitted. It'll allow peer nodes to see this shred
-                                    // and trigger them to mark the slot as dead.
-                                    if shred.index() >= (MAX_DATA_SHREDS_PER_SLOT - 1) as u32 {
-                                        let _ = blockstore.set_dead_slot(shred.slot());
-                                    }
                                     packet.meta.slot = shred.slot();
                                     packet.meta.seed = shred.seed();
                                     Some((shred, repair_info))
@@ -334,6 +362,9 @@ impl WindowService {
             + std::marker::Send
             + std::marker::Sync,
     {
+        let outstanding_requests: Arc<RwLock<OutstandingRepairs>> =
+            Arc::new(RwLock::new(OutstandingRequests::default()));
+
         let bank_forks = Some(repair_info.bank_forks.clone());
 
         let repair_service = RepairService::new(
@@ -344,6 +375,7 @@ impl WindowService {
             repair_info,
             cluster_slots,
             verified_vote_receiver,
+            outstanding_requests.clone(),
         );
 
         let (insert_sender, insert_receiver) = unbounded();
@@ -364,6 +396,7 @@ impl WindowService {
             insert_receiver,
             duplicate_sender,
             completed_data_sets_sender,
+            outstanding_requests,
         );
 
         let t_window = Self::start_recv_window_thread(
@@ -424,6 +457,7 @@ impl WindowService {
         insert_receiver: CrossbeamReceiver<(Vec<Shred>, Vec<Option<RepairMeta>>)>,
         check_duplicate_sender: CrossbeamSender<Shred>,
         completed_data_sets_sender: CompletedDataSetsSender,
+        outstanding_requests: Arc<RwLock<OutstandingRepairs>>,
     ) -> JoinHandle<()> {
         let exit = exit.clone();
         let blockstore = blockstore.clone();
@@ -453,6 +487,7 @@ impl WindowService {
                         &handle_duplicate,
                         &mut metrics,
                         &completed_data_sets_sender,
+                        &outstanding_requests,
                     ) {
                         if Self::should_exit_on_error(e, &mut handle_timeout, &handle_error) {
                             break;
@@ -572,7 +607,7 @@ impl WindowService {
 #[cfg(test)]
 mod test {
     use super::*;
-    use crate::contact_info::ContactInfo;
+    use solana_gossip::contact_info::ContactInfo;
     use solana_ledger::{
         blockstore::{make_many_slot_entries, Blockstore},
         entry::{create_ticks, Entry},
@@ -629,63 +664,94 @@ mod test {
         let mut shreds = local_entries_to_shred(&[Entry::default()], 0, 0, &leader_keypair);
 
         // with a Bank for slot 0, shred continues
-        assert_eq!(
-            should_retransmit_and_persist(&shreds[0], Some(bank.clone()), &cache, &me_id, 0, 0),
-            true
-        );
+        assert!(should_retransmit_and_persist(
+            &shreds[0],
+            Some(bank.clone()),
+            &cache,
+            &me_id,
+            0,
+            0
+        ));
         // with the wrong shred_version, shred gets thrown out
-        assert_eq!(
-            should_retransmit_and_persist(&shreds[0], Some(bank.clone()), &cache, &me_id, 0, 1),
-            false
-        );
+        assert!(!should_retransmit_and_persist(
+            &shreds[0],
+            Some(bank.clone()),
+            &cache,
+            &me_id,
+            0,
+            1
+        ));
 
         // If it's a coding shred, test that slot >= root
-        let (common, coding) = Shredder::new_coding_shred_header(5, 5, 5, 6, 6, 0, 0);
+        let (common, coding) = Shredder::new_coding_shred_header(5, 5, 5, 6, 6, 0);
         let mut coding_shred =
             Shred::new_empty_from_header(common, DataShredHeader::default(), coding);
         Shredder::sign_shred(&leader_keypair, &mut coding_shred);
-        assert_eq!(
-            should_retransmit_and_persist(&coding_shred, Some(bank.clone()), &cache, &me_id, 0, 0),
-            true
-        );
-        assert_eq!(
-            should_retransmit_and_persist(&coding_shred, Some(bank.clone()), &cache, &me_id, 5, 0),
-            true
-        );
-        assert_eq!(
-            should_retransmit_and_persist(&coding_shred, Some(bank.clone()), &cache, &me_id, 6, 0),
-            false
-        );
+        assert!(should_retransmit_and_persist(
+            &coding_shred,
+            Some(bank.clone()),
+            &cache,
+            &me_id,
+            0,
+            0
+        ));
+        assert!(should_retransmit_and_persist(
+            &coding_shred,
+            Some(bank.clone()),
+            &cache,
+            &me_id,
+            5,
+            0
+        ));
+        assert!(!should_retransmit_and_persist(
+            &coding_shred,
+            Some(bank.clone()),
+            &cache,
+            &me_id,
+            6,
+            0
+        ));
 
         // with a Bank and no idea who leader is, shred gets thrown out
         shreds[0].set_slot(MINIMUM_SLOTS_PER_EPOCH as u64 * 3);
-        assert_eq!(
-            should_retransmit_and_persist(&shreds[0], Some(bank.clone()), &cache, &me_id, 0, 0),
-            false
-        );
+        assert!(!should_retransmit_and_persist(
+            &shreds[0],
+            Some(bank.clone()),
+            &cache,
+            &me_id,
+            0,
+            0
+        ));
 
         // with a shred where shred.slot() == root, shred gets thrown out
         let slot = MINIMUM_SLOTS_PER_EPOCH as u64 * 3;
         let shreds = local_entries_to_shred(&[Entry::default()], slot, slot - 1, &leader_keypair);
-        assert_eq!(
-            should_retransmit_and_persist(&shreds[0], Some(bank.clone()), &cache, &me_id, slot, 0),
-            false
-        );
+        assert!(!should_retransmit_and_persist(
+            &shreds[0],
+            Some(bank.clone()),
+            &cache,
+            &me_id,
+            slot,
+            0
+        ));
 
         // with a shred where shred.parent() < root, shred gets thrown out
         let slot = MINIMUM_SLOTS_PER_EPOCH as u64 * 3;
         let shreds =
             local_entries_to_shred(&[Entry::default()], slot + 1, slot - 1, &leader_keypair);
-        assert_eq!(
-            should_retransmit_and_persist(&shreds[0], Some(bank), &cache, &me_id, slot, 0),
-            false
-        );
+        assert!(!should_retransmit_and_persist(
+            &shreds[0],
+            Some(bank),
+            &cache,
+            &me_id,
+            slot,
+            0
+        ));
 
         // if the shred came back from me, it doesn't continue, whether or not I have a bank
-        assert_eq!(
-            should_retransmit_and_persist(&shreds[0], None, &cache, &me_id, 0, 0),
-            false
-        );
+        assert!(!should_retransmit_and_persist(
+            &shreds[0], None, &cache, &me_id, 0, 0
+        ));
     }
 
     #[test]
@@ -719,4 +785,31 @@ mod test {
             duplicate_shred_slot
         );
     }
+
+    #[test]
+    fn test_prune_shreds() {
+        use crate::serve_repair::RepairType;
+        use std::net::{IpAddr, Ipv4Addr};
+        solana_logger::setup();
+        let (common, coding) = Shredder::new_coding_shred_header(5, 5, 5, 6, 6, 0);
+        let shred = Shred::new_empty_from_header(common, DataShredHeader::default(), coding);
+        let mut shreds = vec![shred.clone(), shred.clone(), shred];
+        let _from_addr = SocketAddr::new(IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)), 8080);
+        let repair_meta = RepairMeta {
+            _from_addr,
+            nonce: 0,
+        };
+        let outstanding_requests = Arc::new(RwLock::new(OutstandingRepairs::default()));
+        let repair_type = RepairType::Orphan(9);
+        let nonce = outstanding_requests
+            .write()
+            .unwrap()
+            .add_request(repair_type, timestamp());
+        let repair_meta1 = RepairMeta { _from_addr, nonce };
+        let mut repair_infos = vec![None, Some(repair_meta), Some(repair_meta1)];
+        prune_shreds_invalid_repair(&mut shreds, &mut repair_infos, &outstanding_requests);
+        assert_eq!(repair_infos.len(), 2);
+        assert!(repair_infos[0].is_none());
+        assert_eq!(repair_infos[1].as_ref().unwrap().nonce, nonce);
+    }
 }
