@@ -39,11 +39,8 @@ mod tests {
     use crossbeam_channel::unbounded;
     use fs_extra::dir::CopyOptions;
     use itertools::Itertools;
-    use solana_core::{
-        cluster_info::ClusterInfo,
-        contact_info::ContactInfo,
-        snapshot_packager_service::{PendingSnapshotPackage, SnapshotPackagerService},
-    };
+    use solana_core::snapshot_packager_service::{PendingSnapshotPackage, SnapshotPackagerService};
+    use solana_gossip::{cluster_info::ClusterInfo, contact_info::ContactInfo};
     use solana_runtime::{
         accounts_background_service::{AbsRequestSender, SnapshotRequestHandler},
         accounts_db,
@@ -52,7 +49,7 @@ mod tests {
         bank_forks::{ArchiveFormat, BankForks, SnapshotConfig},
         genesis_utils::{create_genesis_config, GenesisConfigInfo},
         snapshot_utils,
-        snapshot_utils::SnapshotVersion,
+        snapshot_utils::{SnapshotVersion, DEFAULT_MAX_SNAPSHOTS_TO_RETAIN},
         status_cache::MAX_CACHE_ENTRIES,
     };
     use solana_sdk::{
@@ -120,6 +117,7 @@ mod tests {
                 snapshot_path: PathBuf::from(snapshot_dir.path()),
                 archive_format: ArchiveFormat::TarBzip2,
                 snapshot_version,
+                maximum_snapshots_to_retain: DEFAULT_MAX_SNAPSHOTS_TO_RETAIN,
             };
             bank_forks.set_snapshot_config(Some(snapshot_config.clone()));
             SnapshotTestConfig {
@@ -166,6 +164,7 @@ mod tests {
             None,
             AccountSecondaryIndexes::default(),
             false,
+            None,
         )
         .unwrap();
 
@@ -248,7 +247,11 @@ mod tests {
             snapshot_package,
             Some(&last_bank.get_thread_pool()),
         );
-        snapshot_utils::archive_snapshot_package(&snapshot_package).unwrap();
+        snapshot_utils::archive_snapshot_package(
+            &snapshot_package,
+            DEFAULT_MAX_SNAPSHOTS_TO_RETAIN,
+        )
+        .unwrap();
 
         // Restore bank from snapshot
         let account_paths = &[snapshot_test_config.accounts_dir.path().to_path_buf()];
@@ -442,6 +445,7 @@ mod tests {
             None,
             &exit,
             &cluster_info,
+            DEFAULT_MAX_SNAPSHOTS_TO_RETAIN,
         );
 
         let thread_pool = accounts_db::make_min_priority_thread_pool();
